Struct rawdio::Convolution
source · pub struct Convolution {
pub node: GraphNode,
pub wet: AudioParameter,
pub dry: AudioParameter,
}Expand description
A convolution node to convolve the input signal with an impulse response
Fields
node: GraphNodeThe node to connect into the audio graph
wet: AudioParameterThe gain applied to the wet (processed signal) in the output
dry: AudioParameterThe gain applied to the dry (input signal) in the output
Implementations
sourceimpl Convolution
impl Convolution
sourcepub fn new(
context: &dyn Context,
input_count: usize,
impulse: OwnedAudioBuffer
) -> Self
pub fn new( context: &dyn Context, input_count: usize, impulse: OwnedAudioBuffer ) -> Self
Create a new convolution node using the given impulse response